@@ -18,7 +18,7 @@ use Test::Timer::TimeoutException;
 
 @EXPORT = qw(time_ok time_nok time_atleast time_atmost time_between);
 
-$VERSION = '2.05';
+$VERSION = '2.06';
 
 my $test  = Test::Builder->new;
 my $timeout = 0;
@@ -196,6 +196,9 @@ sub _benchmark {
     # running code
     &{$code};
 
+    # clear alarm
+    alarm( 0 );
+
     # setting second benchmark
     my $t1 = new Benchmark;
 
@@ -246,7 +249,7 @@ Test::Timer - test module to test/assert response times
 
 =head1 VERSION
 
-The documentation describes version 2.05 of Test::Timer
+The documentation describes version 2.06 of Test::Timer
 
 =head1 FEATURES
 
